@@ -240,11 +240,6 @@ class TDA():
 
         objectName = objectName.replace("\\", "/")
 
-        specialCharList = [";", "'", '"']
-        for specialChar in specialCharList:
-            if specialChar in filepath:
-                raise Exception(f"filepath can not contained a special chars {specialCharList}")
-
         file = File(filepath, objectName.strip("/"), self.filePrefix, self.dataset.endpoint, self.dataset.datasetType)
         self.fileList.append(file)
         if self.debug:
