@@ -59,7 +59,7 @@ class CommitDb():
         self.conn = sqlite3.connect(self.dbFile)
         self.cur = self.conn.cursor()
         try:
-            res = self.cur.execute(f"SELECT * FROM TDADATA WHERE filepath = '{filepath}'")
+            res = self.cur.execute("SELECT * FROM TDADATA WHERE filepath = ?", (filepath, ))
             return res
         except:
             return None
@@ -72,7 +72,7 @@ class CommitDb():
         for file in data:
             file.SelfCheck()
             try:
-                self.cur.execute(f"SELECT * FROM TDADATA WHERE filepath = '{file.filepath}'")
+                self.cur.execute("SELECT * FROM TDADATA WHERE filepath = ?", (file.filepath,))
                 res = self.cur.fetchone()
                 if res != None:
                     print(file.filepath + " already commited, continue! you can updload them whenever you want.")
